@@ -8,7 +8,12 @@ import jsii
 import jsii.compat
 import publication
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/cdk-assets-schema", "1.49.1", __name__[0:-6], "cdk-assets-schema@1.49.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/cdk-assets-schema",
+    "1.50.0",
+    __name__[0:-6],
+    "cdk-assets-schema@1.50.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
